==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/he.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "שיתוף שרת לשרת לא מופעל בשרת זה",
    "The mountpoint name contains invalid characters." : "שם ה- mountpoint מכיל תווים לא חוקיים.",
    "Not allowed to create a federated share with the same user server" : "יצירת שיתוף מאוגד עם אותו שרת משתמש אסורה",
    "Invalid or untrusted SSL certificate" : "תעודת SSL לא חוקית או לא בטוחה",
    "Could not authenticate to remote share, password might be wrong" : "לא ניתן לאמת שיתוף חיצוני, ייתכן שהסיסמא שגוייה",
    "Storage not valid" : "אחסון לא חוקי",
    "Couldn't add remote share" : "לא ניתן להוסיף שיתוף חיצוני",
    "Shared with you" : "שיתף/שיתפה אתך",
    "Shared with others" : "משותף עם אחרים",
    "Shared by link" : "משותף עם קישור",
    "Federated sharing" : "שיתוף מאוגד",
    "Nothing shared with you yet" : "עדיין לא שיתפו אתך דבר",
    "Files and folders others share with you will show up here" : "קבצים ותיקיות שאחרים שיתפו אתך יוצגו כאן",
    "Nothing shared yet" : "עדיין לא שותף דבר",
    "Files and folders you share will show up here" : "קבצים ותיקיות ששיתפת יוצגו כאן",
    "No shared links" : "אין קישורים משותפים",
    "Files and folders you share by link will show up here" : "קבצים ותיקיות ששיתפת עם קישור יוצגו כאן",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "האם לשתף את השיתוף החיצוני {name} שהתקבל מ- {owner}@{remote}?",
    "Remote share" : "שיתוף חיצוני",
    "Remote share password" : "סיסמת שיתוף חיצוני",
    "Cancel" : "ביטול",
    "Add remote share" : "הוספת שיתוף חיצוני",
    "You can upload into this folder" : "ניתן להעלות לתיקייה זו",
    "No ownCloud installation (7 or higher) found at {remote}" : "לא נמצאה התקנת ownCloud (גרסה 7 ומעלה) ב- {remote}",
    "Invalid ownCloud url" : "נתיב ownCloud לא חוקי",
    "Shared by" : "שותף על־ידי",
    "Sharing" : "שיתוף",
    "A file or folder has been <strong>shared</strong>" : "קובץ או תיקייה <strong>שותפו<strong/>",
    "A file or folder was shared from <strong>another server</strong>" : "קובץ או תיקייה שותפו מ- <strong>שרת אחר</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "קובץ או תיקייה עם שיתוף ציבורי <strong>הורדו</strong>",
    "You received a new remote share %2$s from %1$s" : "קבלת שיתוף חיצוני חדש %2$s מאת %1$s",
    "You received a new remote share from %s" : "קבלת שיתוף חיצוני חדש מאת %s",
    "%1$s accepted remote share %2$s" : "%1$s אישר/אישרה שיתוף חיצוני %2$s",
    "%1$s declined remote share %2$s" : "%1$s סירב/סירבה שיתוף חיצוני %2$s",
    "%1$s unshared %2$s from you" : "%1$s ביטל/ביטלה שיתוף %2$s אתך",
    "Public shared folder %1$s was downloaded" : "תיקיית שיתוף ציבורית %1$s הורדה",
    "Public shared file %1$s was downloaded" : "קובץ שיתוף ציבורי %1$s הורד",
    "You shared %1$s with %2$s" : "שיתפת %1$s עם %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s שיתף/שיתפה %1$s עם %3$s",
    "You removed the share of %2$s for %1$s" : "הסרת את השיתוף של %2$s עבור %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s הסיר/ה את השיתוף של %3$s עבור %1$s",
    "You shared %1$s with group %2$s" : "שיתפת %1$s עם קבוצת %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s שיתף/שיתפה %1$s עם קבוצה %3$s",
    "You removed the share of group %2$s for %1$s" : "הסרת את השיתוף לקבוצה %2$s עבור %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s הסיר/ה את השיתוף לקבוצה %3$s עבור %1$s",
    "%2$s shared %1$s via link" : "%2$s שיתף/שיתפה %1$s על ידי קישור",
    "You shared %1$s via link" : "שיתפת %1$s על בסיס קישור",
    "You removed the public link for %1$s" : "הסרת את הקישור הציבורי של %1$s",
    "%2$s removed the public link for %1$s" : "%2$s הסיר/ה את הקישור הציבורי של %1$s",
    "Your public link for %1$s expired" : "הקישור הציבורי של %1$s פג תוקף",
    "The public link of %2$s for %1$s expired" : "הקישור הציבורי של %2$s עבור %1$s פג תוקף",
    "%2$s shared %1$s with you" : "%2$s שיתפו %1$s אתך",
    "%2$s removed the share for %1$s" : "%2$s הסיר/ה את השיתוף של %1$s",
    "Downloaded via public link" : "הורד על בסיס קישור ציבורי",
    "Shared with %2$s" : "שיתף/שיתפה עם %2$s",
    "Shared with %3$s by %2$s" : "שיתף/שיתפה עם %3$s על ידי %2$s",
    "Removed share for %2$s" : "הסיר/ה שיתוף של %2$s",
    "%2$s removed share for %3$s" : "%2$s הסיר/ה שיתוף של %3$s",
    "Shared with group %2$s" : "שיתף/שיתפה עם קבוצה %2$s",
    "Shared with group %3$s by %2$s" : "שיתף/שיתפה עם קבוצה %3$s על ידי %2$s",
    "Removed share of group %2$s" : "הסיר/ה שיתוף של קבוצה %2$s",
    "%2$s removed share of group %3$s" : "%2$s הסיר/ה שיתוף של קבוצה %3$s",
    "Shared via link by %2$s" : "שיתף/שיתפה על בסיס קישור על ידי %2$s",
    "Shared via public link" : "משותף על בסיס קישור ציבורי",
    "Removed public link" : "הסיר/ה קישור ציבורי",
    "%2$s removed public link" : "%2$s הסיר/ה קישור ציבורי",
    "Public link expired" : "קישור ציבורי פג תוקף",
    "Public link of %2$s expired" : "קישור ציבורי של %2$s פג תוקף",
    "Shared by %2$s" : "שיתף/שיתפה על ידי %2$s",
    "Shares" : "שיתופים",
    "You received \"/%2$s\" as a remote share from %1$s" : "קבלת \"/%2$s\" כשיתוף חיצוני מאת %1$s",
    "Accept" : "אישור",
    "Decline" : "סירוב",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "שיתוף איתי באמצעות מספר זהות שרת ה- #ownCloud המאוגד שלי, ניתן לראות %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "שיתוף איתי באמצעות מספר זהות שרת ה- #ownCloud המאוגד שלי",
    "This share is password-protected" : "שיתוף זה מוגן סיסמא",
    "The password is wrong. Try again." : "הסיסמא שגויה. יש לנסות שנית.",
    "Password" : "סיסמא",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Name" : "שם",
    "Share time" : "זמן שיתוף",
    "Sorry, this link doesn’t seem to work anymore." : "מצטערים, לא נראה שקישור זה עובד יותר. ",
    "Reasons might be:" : "הסיבות יכולות להיות:",
    "the item was removed" : "הפריט הוסר",
    "the link expired" : "הקישור פג תוקף",
    "sharing is disabled" : "השיתוף נוטרל",
    "For more info, please ask the person who sent this link." : "למידע נוסף, יש לפנות לשולח קישור זה.",
    "Add to your ownCloud" : "הוספה ל- ownCloud שלך",
    "Download" : "הורדה",
    "Download %s" : "הורדה %s",
    "Direct link" : "קישור ישיר",
    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
    "Open documentation" : "תיעוד פתוח",
    "Allow users on this server to send shares to other servers" : "מאפשר למשתמשים בשרת זה לשלוח שיתופים לשרתים אחרים",
    "Allow users on this server to receive shares from other servers" : "מאפשר למשתמשים בשרת זה לקבל שיתופים משרתים אחרים",
    "Federated Cloud" : "ענן מאוגד",
    "Your Federated Cloud ID:" : "מספר זיהוי הענן המאוגד שלך:",
    "Share it:" : "שיתוף שלו:",
    "Add to your website" : "הוספה לאתר האינטרנט שלך",
    "Share with me via ownCloud" : "שיתוף איתי באמצעות ownCloud",
    "HTML Code:" : "קוד HTML:",
    "Public link of %2$s expired" : "קישור ציבורי של %2$s פג תוקף",
    "Public shared file %1$s was downloaded" : "קובץ שיתוף ציבורי %1$s הורד",
    "Public shared folder %1$s was downloaded" : "תיקיית שיתוף ציבורית %1$s הורדה",
    "Removed share for %2$s" : "הסיר/ה שיתוף של %2$s",
    "Removed share of group %2$s" : "הסיר/ה שיתוף של קבוצה %2$s",
    "Shared by %2$s" : "שיתף/שיתפה על ידי %2$s",
    "Shared via link by %2$s" : "שיתף/שיתפה על בסיס קישור על ידי %2$s",
    "Shared with group %3$s by %2$s" : "שיתף/שיתפה עם קבוצה %3$s על ידי %2$s",
    "The public link of %2$s for %1$s expired" : "הקישור הציבורי של %2$s עבור %1$s פג תוקף",
    "You removed the public link for %1$s" : "הסרת את הקישור הציבורי של %1$s",
    "You removed the share of %2$s for %1$s" : "הסרת את השיתוף של %2$s עבור %1$s",
    "You removed the share of group %2$s for %1$s" : "הסרת את השיתוף לקבוצה %2$s עבור %1$s",
    "Your public link for %1$s expired" : "הקישור הציבורי של %1$s פג תוקף"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/he.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "שיתוף שרת לשרת לא מופעל בשרת זה",
    "The mountpoint name contains invalid characters." : "שם ה- mountpoint מכיל תווים לא חוקיים.",
    "Not allowed to create a federated share with the same user server" : "יצירת שיתוף מאוגד עם אותו שרת משתמש אסורה",
    "Invalid or untrusted SSL certificate" : "תעודת SSL לא חוקית או לא בטוחה",
    "Could not authenticate to remote share, password might be wrong" : "לא ניתן לאמת שיתוף חיצוני, ייתכן שהסיסמא שגוייה",
    "Storage not valid" : "אחסון לא חוקי",
    "Couldn't add remote share" : "לא ניתן להוסיף שיתוף חיצוני",
    "Shared with you" : "שיתף/שיתפה אתך",
    "Shared with others" : "משותף עם אחרים",
    "Shared by link" : "משותף עם קישור",
    "Anonymous upload" : "העלאה אנונימית",
    "Click to select files or use drag & drop to upload" : "ניתן ללחוץ לבחירת קבצים או להשתמש בגרירה ועזיבה לצורך העלאה",
    "Uploaded files" : "קבצים שהועלו",
    "Uploading..." : "העלאה...",
    "Nothing shared with you yet" : "עדיין לא שיתפו אתך דבר",
    "Files and folders others share with you will show up here" : "קבצים ותיקיות שאחרים שיתפו אתך יוצגו כאן",
    "Nothing shared yet" : "עדיין לא שותף דבר",
    "Files and folders you share will show up here" : "קבצים ותיקיות ששיתפת יוצגו כאן",
    "No shared links" : "אין קישורים משותפים",
    "Files and folders you share by link will show up here" : "קבצים ותיקיות ששיתפת עם קישור יוצגו כאן",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "האם לשתף את השיתוף החיצוני {name} שהתקבל מ- {owner}@{remote}?",
    "Remote share" : "שיתוף חיצוני",
    "Remote share password" : "סיסמת שיתוף חיצוני",
    "Cancel" : "ביטול",
    "Add remote share" : "הוספת שיתוף חיצוני",
    "You can upload into this folder" : "ניתן להעלות לתיקייה זו",
    "No ownCloud installation (7 or higher) found at {remote}" : "לא נמצאה התקנת ownCloud (גרסה 7 ומעלה) ב- {remote}",
    "Invalid ownCloud url" : "נתיב ownCloud לא חוקי",
    "Share" : "שיתוף",
    "No expiration date set" : "לא הוגדר תאריך תפוגה",
    "Shared by" : "שותף על־ידי",
    "Sharing" : "שיתוף",
    "Share API is disabled" : "שיתוף API מנוטרל",
    "Wrong share ID, share doesn't exist" : "מספר זיהוי שיתוף שגוי, שיתוף אינו קיים",
    "Could not delete share" : "לא ניתן היה למחוק את השיתוף",
    "Please specify a file or folder path" : "יש לספק נתיב לקובץ או תיקייה",
    "Wrong path, file/folder doesn't exist" : "נתיב שגוי, קובץ/תיקייה אינם קיימים",
    "Cannot remove all permissions" : "לא ניתן להסיר את כל ההרשאות",
    "Please specify a valid user" : "יש לספק משתמש חוקי",
    "Group sharing is disabled by the administrator" : "שיתוף קבוצתי מנוטרל על ידי המנהל",
    "Please specify a valid group" : "יש לספק קבוצה חוקית",
    "Public link sharing is disabled by the administrator" : "שיתוף ציבורי מנוטרל על ידי המנהל",
    "Public upload disabled by the administrator" : "שיתוף ציבורי מנוטרל על ידי המנהל",
    "Public upload is only possible for publicly shared folders" : "העלאה ציבורית אפשרית רק אל תיקיות משותפות ציבוריות",
    "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "שיתוף %s נכשל כיוון שהצד האחרוי ינו מאפשר שיתוף מסוג %s",
    "Unknown share type" : "סוג שיתוף אינו מוכר",
    "Not a directory" : "אינה תיקייה",
    "Could not lock path" : "לא ניתן היה לנעול נתיב",
    "Can't change permissions for public share links" : "לא ניתן לשנות הרשאות לקישורי שיתוף ציבוריים",
    "Wrong or no update parameter given" : "משתנה עדכון שניתן שגוי או לא קיים",
    "Cannot increase permissions" : "לא ניתן להעלות הרשאות",
    "A file or folder has been <strong>shared</strong>" : "קובץ או תיקייה <strong>שותפו<strong/>",
    "A file or folder was shared from <strong>another server</strong>" : "קובץ או תיקייה שותפו מ- <strong>שרת אחר</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "קובץ או תיקייה עם שיתוף ציבורי <strong>הורדו</strong>",
    "You received a new remote share %2$s from %1$s" : "קבלת שיתוף חיצוני חדש %2$s מאת %1$s",
    "You received a new remote share from %s" : "קבלת שיתוף חיצוני חדש מאת %s",
    "%1$s accepted remote share %2$s" : "%1$s אישר/אישרה שיתוף חיצוני %2$s",
    "%1$s declined remote share %2$s" : "%1$s סירב/סירבה שיתוף חיצוני %2$s",
    "%1$s unshared %2$s from you" : "%1$s ביטל/ביטלה שיתוף %2$s אתך",
    "Public shared folder %1$s was downloaded" : "תיקיית שיתוף ציבורית %1$s הורדה",
    "Public shared file %1$s was downloaded" : "קובץ שיתוף ציבורי %1$s הורד",
    "You shared %1$s with %2$s" : "שיתפת %1$s עם %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s שיתף/שיתפה %1$s עם %3$s",
    "You removed the share of %2$s for %1$s" : "הסרת את השיתוף של %2$s עבור %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s הסיר/ה את השיתוף של %3$s עבור %1$s",
    "You shared %1$s with group %2$s" : "שיתפת %1$s עם קבוצת %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s שיתף/שיתפה %1$s עם קבוצה %3$s",
    "You removed the share of group %2$s for %1$s" : "הסרת את השיתוף לקבוצה %2$s עבור %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s הסיר/ה את השיתוף לקבוצה %3$s עבור %1$s",
    "%2$s shared %1$s via link" : "%2$s שיתף/שיתפה %1$s על ידי קישור",
    "You shared %1$s via link" : "שיתפת %1$s על בסיס קישור",
    "You removed the public link for %1$s" : "הסרת את הקישור הציבורי של %1$s",
    "%2$s removed the public link for %1$s" : "%2$s הסיר/ה את הקישור הציבורי של %1$s",
    "Your public link for %1$s expired" : "הקישור הציבורי של %1$s פג תוקף",
    "The public link of %2$s for %1$s expired" : "הקישור הציבורי של %2$s עבור %1$s פג תוקף",
    "%2$s shared %1$s with you" : "%2$s שיתפו %1$s אתך",
    "%2$s removed the share for %1$s" : "%2$s הסיר/ה את השיתוף של %1$s",
    "Downloaded via public link" : "הורד על בסיס קישור ציבורי",
    "Shared with %2$s" : "שיתף/שיתפה עם %2$s",
    "Shared with %3$s by %2$s" : "שיתף/שיתפה עם %3$s על ידי %2$s",
    "Removed share for %2$s" : "הסיר/ה שיתוף של %2$s",
    "%2$s removed share for %3$s" : "%2$s הסיר/ה שיתוף של %3$s",
    "Shared with group %2$s" : "שיתף/שיתפה עם קבוצה %2$s",
    "Shared with group %3$s by %2$s" : "שיתף/שיתפה עם קבוצה %3$s על ידי %2$s",
    "Removed share of group %2$s" : "הסיר/ה שיתוף של קבוצה %2$s",
    "%2$s removed share of group %3$s" : "%2$s הסיר/ה שיתוף של קבוצה %3$s",
    "Shared via link by %2$s" : "שיתף/שיתפה על בסיס קישור על ידי %2$s",
    "Shared via public link" : "משותף על בסיס קישור ציבורי",
    "Removed public link" : "הסיר/ה קישור ציבורי",
    "%2$s removed public link" : "%2$s הסיר/ה קישור ציבורי",
    "Public link expired" : "קישור ציבורי פג תוקף",
    "Public link of %2$s expired" : "קישור ציבורי של %2$s פג תוקף",
    "Shared by %2$s" : "שיתף/שיתפה על ידי %2$s",
    "Shares" : "שיתופים",
    "This share is password-protected" : "שיתוף זה מוגן סיסמא",
    "The password is wrong. Try again." : "הסיסמא שגויה. יש לנסות שנית.",
    "Password" : "סיסמא",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Name" : "שם",
    "Share time" : "זמן שיתוף",
    "Expiration date" : "תאריך התפוגה",
    "Sorry, this link doesn’t seem to work anymore." : "מצטערים, לא נראה שקישור זה עובד יותר. ",
    "Reasons might be:" : "הסיבות יכולות להיות:",
    "the item was removed" : "הפריט הוסר",
    "the link expired" : "הקישור פג תוקף",
    "sharing is disabled" : "השיתוף נוטרל",
    "For more info, please ask the person who sent this link." : "למידע נוסף, יש לפנות לשולח קישור זה.",
    "%s is publicly shared" : "%s בשיתוף ציבורי",
    "Add to your ownCloud" : "הוספה ל- ownCloud שלך",
    "Download" : "הורדה",
    "Download %s" : "הורדה %s",
    "Direct link" : "קישור ישיר"
},
"nplurals=2; plural=(n != 1);");
